# fastinference
> A collection of inference modules for fastai including inference speedup and interpretability


## Install

`pip install fastinference`

There are submodules available as well via:

* `pip install fastinference[interp]` - Interpretability modules such as SHAP and Feature Importance
* `pip install fastinference[onnxcpu]` - ONNX for a CPU environment
* `pip install fastinference[onnxgpu]` - ONNX for a GPU environment


## Wonderful Contributors:

(Using both their `fastai` handles as well as their GitHub handles if possible):

* Pavel (Pak)
